@@ -308,7 +308,7 @@ function (formula, data, type="MLEfrailty",...)
     m[[1]] <- as.name("model.frame")
     m <- eval(m, sys.parent())
     n <- nrow(m)
-    Y <- model.extract(m, response)
+    Y <- model.extract(m, "response")
     if (!is.Survr(Y)) 
         stop("Response must be a survival recurrent object")
     ll <- attr(Terms, "term.labels")
@@ -388,7 +388,7 @@ function (formula, data, q, B=500, boot.F="WC",boot.G="none",...)
     m[[1]] <- as.name("model.frame")
     m <- eval(m, sys.parent())
     n <- nrow(m)
-    Y <- model.extract(m, response)
+    Y <- model.extract(m, "response")
     if (!is.Survr(Y)) 
         stop("Response must be a survival recurrent object")
     ll <- attr(Terms, "term.labels")
